import {select, 
        csv, 
        scaleLinear, 
        extent,
        axisLeft,
        axisBottom,
        scaleTime,
        area,
        curveBasis
       } from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');
const margin = {top: 60, right: 40, bottom: 90, left: 110};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const render = data => {

  const title = 'A week in San Francisco';
  const xValue = d => d.timestamp;
  const xAxisLabel = 'Time';
  
  const yValue = d => d.temperature;
  const yAxisLabel = 'Temperature';
  
  const circleRadius = 6;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth]);
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);

  
  const xAxis = axisBottom(xScale)
  	.ticks(6)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.select('.domain').remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -60)
  	.attr('x', -innerHeight/2)
  	.text(yAxisLabel)
  	.attr('fill', 'black')
  	.attr('transform', `rotate(-90)`)
  	.attr('text-anchor', 'middle');
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 75)
  	.attr('x', innerWidth / 2)
  	.text(xAxisLabel)
  	.attr('fill', 'black');
  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', areaGenerator(data));
  
  g.append('text')
  	.attr('class', 'title')
  	.attr('y', -10)
  	.text(title);
  
};

csv('https://gist.githubusercontent.com/curran/60b40877ef898f19aeb8/raw/9476be5bd15fb15a6d5c733dd79788fb679c9be9/week_temperature_sf.csv')
  .then(data => { 
    data.forEach(d => {
      d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp);
    });
    render(data);
});













